==> vue-form-2.22.1.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var formProps = _extends({}, $props, {
  model: Object,
  rules: Object,
  inlineMessage: {
    type: Boolean,
    default: void 0
  },
  messageType: String,
  statusIcon: Boolean,
  showMessage: {
    type: Boolean,
    default: true
  },
  validatePosition: {
    type: String,
    default: "right"
  },
  size: String,
  disabled: Boolean,
  validateOnRuleChange: {
    type: [Boolean, String],
    validator: function validator(value) {
      return typeof value === "boolean" || ["deep"].includes(value);
    },
    default: true
  },
  hideRequiredAsterisk: {
    type: Boolean,
    default: void 0
  },
  labelPosition: {
    type: String,
    default: "right",
    validator: function validator2(value) {
      return ["left", "top", "right"].includes(value);
    }
  },
  labelWidth: {
    type: String,
    // 默认值挪到design中
    default: ""
  },
  labelAlign: {
    type: Boolean,
    default: false
  },
  contentOffset: Number,
  labelSuffix: {
    type: String,
    default: ""
  },
  inline: {
    type: Boolean,
    default: false
  },
  responsiveLayout: {
    type: Boolean,
    default: false
  },
  validateType: {
    type: String,
    default: "tip",
    validator: function validator3(value) {
      return Boolean(~["tip", "text"].indexOf(value));
    }
  },
  validateIcon: Object,
  manual: {
    type: Boolean,
    default: false
  },
  appendToBody: {
    type: Boolean,
    default: void 0
  },
  popperOptions: {
    type: Object,
    default: function _default() {
      return {};
    }
  },
  displayOnly: {
    type: Boolean,
    default: false
  },
  showAutoWidth: {
    type: Boolean,
    default: false
  },
  showEmptyValue: {
    type: Boolean,
    default: true
  },
  validateTag: {
    type: Boolean,
    default: false
  },
  overflowTitle: {
    type: Boolean,
    default: false
  },
  wrapFragment: {
    type: String,
    default: "div"
  },
  tooltipConfig: {
    type: Object,
    default: function _default2() {
      return {};
    }
  }
});
var Form = defineComponent({
  name: $prefix + "Form",
  componentName: "Form",
  props: formProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.undefined";
Form.install = function(Vue) {
  Vue.component(Form.name, Form);
};
Form.version = version;
export {
  Form as default
};

==> vue-form-2.23.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var formProps = _extends({}, $props, {
  model: Object,
  rules: Object,
  inlineMessage: {
    type: Boolean,
    default: void 0
  },
  messageType: String,
  statusIcon: Boolean,
  showMessage: {
    type: Boolean,
    default: true
  },
  validatePosition: {
    type: String,
    default: "right"
  },
  size: String,
  disabled: Boolean,
  validateOnRuleChange: {
    type: [Boolean, String],
    validator: function validator(value) {
      return typeof value === "boolean" || ["deep"].includes(value);
    },
    default: true
  },
  hideRequiredAsterisk: {
    type: Boolean,
    default: void 0
  },
  labelPosition: {
    type: String,
    default: "right",
    validator: function validator2(value) {
      return ["left", "top", "right"].includes(value);
    }
  },
  labelWidth: {
    type: String,
    // 默认值挪到design中
    default: ""
  },
  labelAlign: {
    type: Boolean,
    default: false
  },
  contentOffset: Number,
  labelSuffix: {
    type: String,
    default: ""
  },
  inline: {
    type: Boolean,
    default: false
  },
  responsiveLayout: {
    type: Boolean,
    default: false
  },
  validateType: {
    type: String,
    default: "tip",
    validator: function validator3(value) {
      return Boolean(~["tip", "text"].indexOf(value));
    }
  },
  validateIcon: Object,
  manual: {
    type: Boolean,
    default: false
  },
  appendToBody: {
    type: Boolean,
    default: void 0
  },
  popperOptions: {
    type: Object,
    default: function _default() {
      return {};
    }
  },
  displayOnly: {
    type: Boolean,
    default: false
  },
  showAutoWidth: {
    type: Boolean,
    default: false
  },
  showEmptyValue: {
    type: Boolean,
    default: true
  },
  validateTag: {
    type: Boolean,
    default: false
  },
  overflowTitle: {
    type: Boolean,
    default: false
  },
  wrapFragment: {
    type: String,
    default: "div"
  },
  tooltipConfig: {
    type: Object,
    default: function _default2() {
      return {};
    }
  }
});
var Form = defineComponent({
  name: $prefix + "Form",
  componentName: "Form",
  props: formProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.23.0";
Form.install = function(Vue) {
  Vue.component(Form.name, Form);
};
Form.version = version;
export {
  Form as default
};
